clear all
close all

% Matlab script to generate test signals with a sine carrier to test filter slopes.
% the m-values in the tested octave band should yield at least m=0.5
% These test signals can be used for algorithm testing, see section C.4.2
% www.stipa.info

STIrevision = 5;

Author  =   'Jan Verhave';
Version =   '1.0';
Date    =   '2 June 2020';
Copyright = 'Embedded Acoustics BV, Netherlands';

fs      =   48000;  % samplerate
T       =   30;    

OCTAVES =   [ 125  250  500  1000 2000 4000 8000];
FMODLO  =   [ 1.6  1.0  0.63  2.0 1.25  0.8  2.5];
FMODHI  =   5*FMODLO;

s       =   [1:fs*T];
t       =   (s-1)/fs;


for i=1:length(OCTAVES)
    G   =   10^(-41/20); % band level
    MOD =   sqrt(0.5*(1+0.55*(sin(2*pi*FMODLO(i)*t)-sin(2*pi*FMODHI(i)*t))));
    CAR =   sin(2*pi*OCTAVES(i)*t);
    y   =   G*MOD.*CAR + 10^(-3/20)*sin(2*pi*OCTAVES(i)/2*t);
    y   =   y/max(abs(y));
    wavwrite(y,fs,['Filtertest_lowslope ' num2str(OCTAVES(i)) '.wav']);
    y   =   G*MOD.*CAR + 10^(-3/20)*sin(2*pi*OCTAVES(i)*2*t);
    y   =   y/max(abs(y));
    wavwrite(y,fs,['Filtertest_highslope ' num2str(OCTAVES(i)) '.wav']);
end









